<?php
/**
 * Testimonial options
 *
 * @package Theme Palace
 * @subpackage Yummy pro
 * @since Yummy Pro 1.0
 */
// Add Testimonial section
$wp_customize->add_section( 'yummy_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial Section','yummy-pro' ),
	'description'       => esc_html__( 'Testimonial options.', 'yummy-pro' ),
	'panel'             => 'yummy_pro_sections_panel',
) );
/**
 * Testimonial Options
 */
// Enable Testimonial.
$wp_customize->add_setting( 'yummy_pro_theme_options[enable_testimonial]', array(
	'default'           => $options['enable_testimonial'],
	'sanitize_callback' => 'yummy_pro_sanitize_checkbox',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[enable_testimonial]', array(
	'label'             => esc_html__( 'Enable Testimonial Section', 'yummy-pro' ),
	'section'           => 'yummy_pro_testimonial_section',
	'type'				=> 'checkbox',
) );

/**
 * Testimonial Header Label.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_header_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Note_Control( $wp_customize, 'yummy_pro_theme_options[testimonial_header_label]', array(
	'label'           	=> esc_html__( 'Header Options', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_testimonial_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'yummy_pro_is_testimonial_section_active',
) ) );

/**
 * Testimonial Header type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_header_type]', array(
	'default'           => $options['testimonial_header_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[testimonial_header_type]', array(
	'active_callback'	=> 'yummy_pro_is_testimonial_section_active',
	'label'             => esc_html__( 'Header Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_testimonial_section',
	'choices'			=> yummy_pro_special_item_header_type_options(),
	'type'				=> 'select',
) );

/**
 * Title Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_header_title]', array(
	'default'           => $options['testimonial_header_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[testimonial_header_title]', array(
	'active_callback'	=> 'yummy_pro_testimonial_header_custom',
	'label'             => esc_html__( 'Title', 'yummy-pro' ),
	'section'           => 'yummy_pro_testimonial_section',
	'type'				=> 'text',
) );

/**
 * Title link Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_header_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[testimonial_header_link]', array(
	'active_callback'	=> 'yummy_pro_testimonial_header_custom',
	'label'             => esc_html__( 'Title Link', 'yummy-pro' ),
	'section'           => 'yummy_pro_testimonial_section',
	'type'				=> 'url',
) );

/**
 * Testimonial image setting and control
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_header_image]', array(
	'default'           => $options['testimonial_header_image'],
	'sanitize_callback' => 'yummy_pro_sanitize_image',
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'yummy_pro_theme_options[testimonial_header_image]',
		array(
		'label'       		=> esc_html__( 'Select Image', 'yummy-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'yummy-pro' ), 1500, 1000 ),
		'section'     		=> 'yummy_pro_testimonial_section',
		'active_callback'	=> 'yummy_pro_testimonial_header_custom',
) ) );

/**
 * Testimonial Header page Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_header_page]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_page',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[testimonial_header_page]', array(
	'active_callback'	=> 'yummy_pro_testimonial_header_page',
	'label'             => esc_html__( 'Select Page', 'yummy-pro' ),
	'description'       => esc_html__( 'Info: Make sure selected page has featured image.', 'yummy-pro' ),
	'section'           => 'yummy_pro_testimonial_section',
	'type'				=> 'dropdown-pages'
) );

/**
 * Testimonial hr setting and control
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Yummy_Pro_Customize_Horizontal_Line( $wp_customize, 'yummy_pro_theme_options[testimonial_hr]',
	array(
		'section'         => 'yummy_pro_testimonial_section',
		'active_callback' => 'yummy_pro_is_testimonial_section_active',
		'type'			  => 'hr'
) ) );

/**
 * Testimonial Content Label.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_content_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Note_Control( $wp_customize, 'yummy_pro_theme_options[testimonial_content_label]', array(
	'label'           	=> esc_html__( 'Content Options', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_testimonial_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'yummy_pro_is_testimonial_section_active',
) ) );

/**
 * Testimonial content type options.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_content_type]', array(
	'default'           => $options['testimonial_content_type'],
	'sanitize_callback' => 'yummy_pro_sanitize_select',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[testimonial_content_type]', array(
	'active_callback'	=> 'yummy_pro_is_testimonial_section_active',
	'label'             => esc_html__( 'Content Type', 'yummy-pro' ),
	'section'           => 'yummy_pro_testimonial_section',
	'choices'			=> yummy_pro_testimonial_content_type_options(),// used this function as it requires same content as special item header content type.
	'type'				=> 'select',
) );

/**
 * Post Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[testimonial_default_posts]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[testimonial_default_posts]', array(
	'active_callback'	=> 'yummy_pro_testimonial_content_post',
	'label'             => esc_html__( 'Input Post Ids', 'yummy-pro' ),
	'description'       => esc_html__( 'Max. posts allowed is 6. ie: 11, 24, 34', 'yummy-pro' ),
	'section'           => 'yummy_pro_testimonial_section',
	'type'				=> 'text',
) );

/**
 * Testimonial Content Label.
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[tp_testimonial_posts_label]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Yummy_Pro_Note_Control( $wp_customize, 'yummy_pro_theme_options[tp_testimonial_posts_label]', array(
	'label'           	=> esc_html__( 'Set the posts ids of Testimonial PostType of TP Philosophy Tools Plugin.', 'yummy-pro' ),
	'section'         	=> 'yummy_pro_testimonial_section',
	'type'            	=> 'description',
	'active_callback' 	=> 'yummy_pro_testimonial_content_testimonial_posts',
) ) );

/**
 * Testimonial Product Content Type Options
 */
$wp_customize->add_setting( 'yummy_pro_theme_options[tp_testimonial_posts]', array(
	'sanitize_callback' => 'yummy_pro_sanitize_post_ids',
) );

$wp_customize->add_control( 'yummy_pro_theme_options[tp_testimonial_posts]', array(
	'active_callback'	=> 'yummy_pro_testimonial_content_testimonial_posts',
	'label'             => esc_html__( 'Input Testimonial Post Ids', 'yummy-pro' ),
	'description'       => esc_html__( 'Max. testimonial allowed is 6. ie: 11, 24, 34', 'yummy-pro' ),
	'section'           => 'yummy_pro_testimonial_section',
	'type'				=> 'text',
) );

