<?php 
/**
 * Call to action section
 *
 * This is the template for the content of call_to_action section
 *
 * @package Yummy Pro
 * @since Yummy Pro 1.0
 */
if ( ! function_exists( 'yummy_pro_add_call_to_action_section' ) ) :
    /**
    * Add Call to action section
    *
    *@since Yummy Pro 1.0
    */
    function yummy_pro_add_call_to_action_section() {
        // Check if call_to_action is enabled
        $enable_call_to_action = apply_filters( 'yummy_pro_section_status', true, 'enable_call_to_action' );

        if ( true !== $enable_call_to_action ) {
            return false;
        }

        // Get call_to_action section details
        $section_details = array();
        $section_details = apply_filters( 'yummy_pro_filter_call_to_action_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render call_to_action section now.
        yummy_pro_render_call_to_action_section( $section_details );
    }
endif;
add_action( 'yummy_pro_primary_content_action', 'yummy_pro_add_call_to_action_section', 40 );


if ( ! function_exists( 'yummy_pro_get_call_to_action_section_details' ) ) :
    /**
    * Call to action section details.
    *
    * @since Yummy Pro 1.0
    * @param array $input call_to_action section details.
    */
    function yummy_pro_get_call_to_action_section_details( $input ) {
        $options = yummy_pro_get_theme_options();

        // call_to_action type
        $call_to_action_type  = $options['call_to_action_type'];

        $content = array();
        switch ( $call_to_action_type ) {

            case 'demo':
                $content[0]['title']        = esc_html__( 'We Cook delicious memory', 'yummy-pro' );
                $content[0]['btn_label']    = esc_html__( 'Buy Now', 'yummy-pro' );
                $content[0]['url']          = '#';
                $content[0]['img_array']    = get_template_directory_uri().'/assets/uploads/memory.jpg';
            break;

          	case 'custom':
                $content[0]['title']        = ! empty( $options['call_to_action_title'] ) ? $options['call_to_action_title'] : '';
                $content[0]['btn_label']    = ! empty( $options['call_to_action_btn_label'] ) ? $options['call_to_action_btn_label'] : '';
                $content[0]['url']          = ! empty( $options['call_to_action_link'] ) ? $options['call_to_action_link'] : '#';
                $content[0]['img_array']    = ! empty( $options['call_to_action_image'] ) ? $options['call_to_action_image'] : get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
            break;

            case 'page':
                $page_id = null;
                if ( ! empty( $options['call_to_action_page'] ) )
                    $page_id = $options['call_to_action_page'];
          	break;
        }

        if ( 'page' == $call_to_action_type ) {
            // Fetch posts.
            if ( ! empty( $page_id ) ) {
                $img_array = array();
                if ( has_post_thumbnail( $page_id ) ) {
                    $img_array     = wp_get_attachment_image_src( get_post_thumbnail_id( $page_id ), 'full' );
                } else {
                    $img_array[0]  = get_template_directory_uri() . '/assets/uploads/no-featured-image-1500x1000.jpg';
                }
                $content[0]['title']        = get_the_title( $page_id );
                $content[0]['url']          = get_the_permalink( $page_id );
                $content[0]['btn_label']    = ! empty( $options['call_to_action_page_btn_label'] ) ? $options['call_to_action_page_btn_label'] : esc_html__( 'View', 'yummy-pro' );
                $content[0]['img_array']    = $img_array[0];
            }
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// call_to_action section content details.
add_filter( 'yummy_pro_filter_call_to_action_section_details', 'yummy_pro_get_call_to_action_section_details' );


if ( ! function_exists( 'yummy_pro_render_call_to_action_section' ) ) :
    /**
    * Start call_to_action section
    *
    * @return string call_to_action content
    * @since Yummy Pro 1.0
    *
    */
    function yummy_pro_render_call_to_action_section( $content_details = array() ) {
        $options = yummy_pro_get_theme_options();

        if ( empty( $content_details ) ) {
          return;
        } 
        
        foreach ( $content_details as $content_detail ) : ?>
            <section id="parallax-2" class="parallax delicious-memory" style="background-image:url('<?php echo esc_url( $content_detail['img_array'] ) ?>');" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="100">
                <div class="black-overlay"></div>
                <div class="wrapper">
                    <header class="entry-header">
                        <?php if ( ! empty( $content_detail['title'] ) ) : ?>
                            <h2 class="entry-title color-white"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h2>
                        <?php endif;
                        if ( ! empty( $content_detail['btn_label'] ) ) : ?>
                            <a href="<?php echo esc_url( $content_detail['url'] ); ?>" class="btn btn-transparent"><?php echo esc_html( $content_detail['btn_label'] ); ?></a>
                        <?php endif; ?>
                    </header>
                </div><!--.wrapper-->
            </section><!-- #parallax-2 -->
    <?php endforeach; 
    }
endif;