<?php 
/**
 * Recipe section
 *
 * This is the template for the content of Recipe section
 *
 * @package Yummy Pro
 * @since Yummy Pro 1.0
 */
if ( ! function_exists( 'yummy_pro_add_recipe_section' ) ) :
    /**
    * Add Recipe section
    *
    *@since Yummy Pro 1.0
    */
    function yummy_pro_add_recipe_section() {
        // Check if slider is enabled
        $enable_recipe = apply_filters( 'yummy_pro_section_status', true, 'enable_recipe' );

        if ( true !== $enable_recipe ) {
            return false;
        }
        // Get Recipe section details
        $section_details = array();
        $section_details = apply_filters( 'yummy_pro_filter_recipe_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render Recipe section now.
        yummy_pro_render_recipe_section( $section_details );
    }
endif;
add_action( 'yummy_pro_primary_content_action', 'yummy_pro_add_recipe_section', 50 );


if ( ! function_exists( 'yummy_pro_get_recipe_section_details' ) ) :
    /**
    * Recipe section details.
    *
    * @since Yummy Pro 1.0
    * @param array $input Recipe section details.
    */
    function yummy_pro_get_recipe_section_details( $input ) {
        $options = yummy_pro_get_theme_options();

        // Slider type
        $recipe_content_type  = $options['recipe_content_type'];

        $content = array();
        switch ( $recipe_content_type ) {
            case 'demo':

                $images = array( 'sandwich.jpg', 'chip.jpg', 'bread.jpg', 'pie.jpg' ); // An array of demo images
                $image_width = array( 410, 90, 90, 90 );
                $image_height = array( 605, 90, 90, 90);
                $title = array( esc_html__( 'Potbelly Sandwich','yummy-pro' ), esc_html__( 'Macadamia chocolate chip','yummy-pro' ), esc_html__( 'Fresh Strawberry Pie','yummy-pro' ), esc_html__( 'Asiago(Featured Bread)','yummy-pro' ) );

                for ( $i=0; $i<4; $i++ ) {
                    $content[$i]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/'.$images[$i];
                    $content[$i]['img_array'][1] = $image_width[$i];
                    $content[$i]['img_array'][2] = $image_height[$i];    
                    $content[$i]['url']          = '#';
                    $content[$i]['title']        = $title[$i];
                    $content[$i]['excerpt']      = esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit.','yummy-pro' );
                    $content[$i]['button_label']   = esc_html__( 'Full Recipe','yummy-pro' );
                }               
            break;        

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['recipe_post_ids'] ) ) {
                    $ids = ( array ) $options['recipe_post_ids'];
                }
                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                );     
            break;

            case 'tp-recipe':
                $ids = array();
                
                if ( ! empty( $options['recipe_post_recipe_ids'] ) ) {
                    $ids = ( array ) $options['recipe_post_recipe_ids'];
                }
                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'post_type'      => 'tp-recipe',
                    'post__in'       => $ids,
                );     
            break;

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['recipe_category'] ) ) {
                    $cat_id = $options['recipe_category'];
                }
                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }
                else {
                    $cat_id =  $cat_id;
                }
                $args = array(
                    'post_type'      => 'post',
                    'posts_per_page' => 4,
                    'cat'            => $cat_id,
                );
            break;

            case 'tp-recipe-category':
                $cat_id = '';
                if ( ! empty( $options['tp_recipe_category'] ) ) {
                    $cat_id = $options['tp_recipe_category'];
                }
                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }
                else {
                    $cat_id =  $cat_id;
                }
                $args = array(
                  'post_type'      => 'tp-recipe',
                  'posts_per_page' => 4,
                  'tax_query'      => array(
                    array(
                        'taxonomy'  => 'tp-recipe-category',
                        'field'     => 'id',
                        'terms'     => $cat_id
                        )
                    ) 
                );
            break;

            default:
            break;
        }

        if ( 'demo' != $recipe_content_type ) {
            // Fetch posts.
            $posts = get_posts( $args );

            if ( ! empty( $posts ) ) {

                $i = 1;
                $index = 1;
                foreach ( $posts as $key => $post ) {
                    $page_id = $post->ID;
                    $img_array = null;
                    if ( has_post_thumbnail( $page_id ) ) {
                        if ( $index == 1 ) {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'medium_large' );
                        }
                        else {
                            $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'thumbnail' );
                        }
                    } 
                    else {
                        if( $index == 1 ) {
                            $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-600x600.jpg';
                            $img_array[1] = 410;
                            $img_array[2] = 605;
                        }
                        else {
                            $img_array[0] =  get_template_directory_uri() . '/assets/uploads/no-featured-image-300x300.jpg';
                            $img_array[1] = 90;
                            $img_array[2] = 90;
                        }
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }
                    $content[ $i ]['url']         = get_permalink( $page_id );
                    $content[ $i ]['title']       = get_the_title( $page_id );
                    $content[ $i ]['excerpt']     = yummy_pro_trim_content( 10, $post );
                    $content[ $i ]['post_id']     = $post->ID;
                    $content[ $i ]['button_label']= $options['button_label'];
                    $i++;
                }
            }
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Recipe section content details.
add_filter( 'yummy_pro_filter_recipe_section_details', 'yummy_pro_get_recipe_section_details' );


if ( ! function_exists( 'yummy_pro_render_recipe_section' ) ) :
    /**
    * Start Recipe section
    *
    * @return string Slider content
    * @since Yummy Pro 1.0
    *
    */
    function yummy_pro_render_recipe_section( $content_details = array() ) {
        
        $options                 = yummy_pro_get_theme_options();
        $recipe_content_type  = $options['recipe_content_type'];
        if ( empty( $content_details ) ) {
          return;
        } 
        $addcolumn = '';
        if( 'post' == $recipe_content_type  || 'category' == $recipe_content_type  ){
            $addcolumn = 2;
        }
        else {
            $addcolumn = 3;
        }
        $index = 1; 
        ?>
        <section id="sandwich-details" class="page-section">
            <div class="wrapper">
            <?php  foreach ( $content_details as $content ) { ?>
                    <header class="entry-header">
                        <div class="entry-header-logo">
                            <img src="<?php echo get_template_directory_uri() . '/assets/uploads/logo-02.png'; ?>" alt="<?php esc_attr_e( 'logo','yummy-pro' ); ?>">
                        </div><!-- .entry-header-logo -->
                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                    </header><!--.entry-header-->
                <div class="entry-content col-<?php echo absint( $addcolumn ); ?>">
                    <div class="row">
            <?php break; } ?>        
                        <div class="column-wrapper">
                        <?php $j = 1;
                        $content_detail = $content_details;
                        array_shift( $content_detail );
                        foreach ( $content_detail as $content ) { ?>
                            <div class="sandwich-item">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" class="alignleft" width="<?php echo absint( $content['img_array'][1] ); ?>" height="<?php echo absint( $content['img_array'][2] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                <h4><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h4>
                                <?php if( ! empty( $content['excerpt'] ) ) { ?>
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                <?php } ?>
                            </div><!--.sandwich-item-->
                        <?php $j++; }
                        foreach( $content_details as $content ) { ?>
                            <div class="method">
                                <h4><?php echo esc_html( $content['title'] ); ?></h4>
                                <?php if( ! empty( $content['excerpt'] ) ) { ?>
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                <?php } 
                                if( ! empty( $content['button_label'] ) ) { ?>
                                <a href="<?php echo esc_url( $content['url'] ); ?>" class="more-link fill-black"><?php echo esc_html( $content['button_label'] ); ?></a>
                                <?php } ?>
                            </div><!--.method-->
                        </div><!--.column-wrapper-->       
                        <div class="column-wrapper">
                            <a href="<?php echo esc_url( $content['url'] ); ?>">
                                <div class="featured-image border-white" style="background-image:url( '<?php echo esc_url( $content['img_array'][0] ); ?>' );">
                                </div><!--.featured-image-->
                            </a>
                        </div><!--.column-wrapper-->
                        <?php if( 3 === $addcolumn ) { ?>
                        <div class="column-wrapper">
                            <div class="total-duration">
                                <div class="inner-wrap">
                                    <div class="duration preparation-time">
                                        <span><?php esc_html_e( 'Prep','yummy-pro' ); ?></span>
                                        <?php if( 'demo' == $recipe_content_type ) {
                                            echo '<span class="time">' . esc_html__( '15','yummy-pro' ) . '</span>';    
                                        }
                                        else {
                                            if ( has_action( 'tp_recipe_prep_time_action' ) ) {
                                                /*
                                                 * @hooked tp_recipe_prep_time
                                                */
                                                do_action( 'tp_recipe_prep_time_action', $content['post_id'] ); 
                                            }
                                        } ?>
                                        <small><?php esc_html_e( 'mins','yummy-pro' ); ?></small>
                                    </div><!-- .preparation-time -->
                                    <div class="duration cooking-time">
                                        <span><?php esc_html_e( 'Cook','yummy-pro' ); ?></span>
                                        <?php if( 'demo' == $recipe_content_type ) {
                                            echo '<span class="time">' . esc_html__( '30','yummy-pro' ) . '</span>';    
                                        }
                                        else { 
                                            if ( has_action( 'tp_recipe_cook_time_action' ) ) {
                                                /*
                                                 * @hooked tp_recipe_cook_time
                                                */
                                                do_action( 'tp_recipe_cook_time_action', $content['post_id'] );  
                                            }
                                            
                                        } ?>
                                        <small><?php esc_html_e( 'mins','yummy-pro' ); ?></small>
                                    </div><!-- .cooking-time -->
                                    <div class="duration ready-time">
                                        <span><?php esc_html_e( 'Ready in','yummy-pro' ); ?></span>
                                        <?php if( 'demo' == $recipe_content_type ) {
                                            echo '<span class="time">' . esc_html__( '50','yummy-pro' ) . '</span>';    
                                        }
                                        else { 
                                            if ( has_action( 'tp_recipe_ready_time_action' ) ) {
                                                /*
                                                 * @hooked tp_recipe_ready_time
                                                */
                                                do_action( 'tp_recipe_ready_time_action', $content['post_id'] );
                                            }
                                        } ?>
                                        <small><?php esc_html_e( 'mins','yummy-pro' ); ?></small>
                                    </div><!-- .preparation-time -->
                                </div><!-- .inner-wrap -->
                            </div><!--.duration-->
                        </div><!--.column-wrapper-->
                        <?php } break; } ?>
                    </div><!--.row-->
                </div><!--.entry-content-->
            </div><!--.wrapper-->
        </section><!-- #sandwich-details -->
    <?php }
endif;